@@ -1,21 +1,10 @@
 use serde::Serialize;
 
 #[derive(Serialize, Debug)]
-pub struct ErrorBars {
-
-}
+pub struct BoxPlot {}
 
 #[derive(Serialize, Debug)]
-pub struct BoxPlot {
-
-}
+pub struct Histogram {}
 
 #[derive(Serialize, Debug)]
-pub struct Histogram {
-
-}
-
-#[derive(Serialize, Debug)]
-pub struct Density {
-
-}
+pub struct Density {}
